"""
Test for the template tag sovtimer_static
"""

# Django
from django.template import Context, Template
from django.test import TestCase

# AA Sovereignty Timer
from sovtimer import __version__


class TestForumVersionedStatic(TestCase):
    """
    Test sovtimer_static template tag
    """

    def test_versioned_static(self):
        """
        Test if we get the right version on our static files
        :return:
        """

        context = Context({"version": __version__})
        template_to_render = Template(
            "{% load sovtimer_versioned_static %}"
            "{% sovtimer_static 'sovtimer/css/aa-sov-timer.min.css' %}"
        )

        rendered_template = template_to_render.render(context)

        self.assertInHTML(
            f'/static/sovtimer/css/aa-sov-timer.min.css?v={context["version"]}',
            rendered_template,
        )



# Standard Library
import re
from typing import List

# Django
from django.contrib.auth.models import User

# Alliance Auth
from allianceauth.tests.auth_utils import AuthUtils


def create_fake_user(
    character_id: int,
    character_name: str,
    corporation_id: int = None,
    corporation_name: str = None,
    corporation_ticker: str = None,
    alliance_id: int = None,
    alliance_name: str = None,
    permissions: List[str] = None,
) -> User:
    """
    Create a fake user incl. main character and (optional) permissions.
    """

    username = re.sub(r"[^\w\d@\.\+-]", "_", character_name)
    user = AuthUtils.create_user(username)

    if not corporation_id:
        corporation_id = 2001
        corporation_name = "Wayne Technologies Inc."
        corporation_ticker = "WTE"

    if not alliance_id:
        alliance_id = 3001
        alliance_name = "Wayne Enterprises"

    AuthUtils.add_main_character_2(
        user=user,
        name=character_name,
        character_id=character_id,
        corp_id=corporation_id,
        corp_name=corporation_name,
        corp_ticker=corporation_ticker,
        alliance_id=alliance_id,
        alliance_name=alliance_name,
    )

    if permissions:
        perm_objs = [AuthUtils.get_permission_by_name(perm) for perm in permissions]
        user = AuthUtils.add_permissions_to_user(perms=perm_objs, user=user)

    return user



# Generated by Django 3.2.11 on 2022-01-29 16:21

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("eveuniverse", "0005_type_materials_and_sections"),
        ("sovtimer", "0005_auto_20201114_0720"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="AaSovtimerStructures",
            new_name="SovereigntyStructure",
        ),
        migrations.RenameModel(
            old_name="AaSovtimerCampaigns",
            new_name="Campaign",
        ),
    ]



# Generated by Django 4.0.3 on 2022-05-25 12:26

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sovtimer", "0007_cleanup_models"),
    ]

    operations = [
        migrations.AlterField(
            model_name="campaign",
            name="attackers_score",
            field=models.FloatField(default=0.4),
        ),
    ]



"""
hook into AA
"""

# Django
from django.utils.translation import gettext_lazy as _

# Alliance Auth
from allianceauth import hooks
from allianceauth.services.hooks import MenuItemHook, UrlHook

# AA Sovereignty Timer
from sovtimer import __title__, urls


class AaSovtimerMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
    """
    This class ensures only authorized users will see the menu entry
    """

    def __init__(self):
        # setup menu entry for sidebar
        MenuItemHook.__init__(
            self,
            _(__title__),
            "far fa-clock fa-fw",
            "sovtimer:dashboard",
            navactive=["sovtimer:"],
        )

    def render(self, request):
        """
        check if the user has the permission to view this app
        :param request:
        :return:
        """

        if request.user.has_perm("sovtimer.basic_access"):
            return MenuItemHook.render(self, request)

        return ""


@hooks.register("menu_item_hook")
def register_menu():
    """
    register our menu item
    :return:
    """

    return AaSovtimerMenuItem()


@hooks.register("url_hook")
def register_urls():
    """
    register our basu url
    :return:
    """

    return UrlHook(urls, "sovtimer", r"^sovereignty-timer/")
